@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Calculate date-time operations
 
-our $VERSION = '0.0203';
+our $VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -82,13 +82,16 @@ sub said {
 
             $body = $dt->$method( $span => $3 );
         }
+        # Exit IRC
+        elsif ( $arguments->{body} =~ /^leave$/ ) {
+            $self->shutdown('I have done my job here.');
+            exit;
+        }
 
         $self->say(
             channel => $arguments->{channel},
             body    => $body,
         );
-
-#        $self->shutdown('I have done my job here.');
     }
 }
 
@@ -121,7 +124,7 @@ Bot::BasicBot::Pluggable::Module::DateTimeCalc - Calculate date-time operations
 
 =head1 VERSION
 
-version 0.0203
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -188,6 +191,12 @@ stamps.
 
 Add or subtract the the given span from the given date-time stamp.
 
+=head2 leave
+
+  > TimeBot: leave
+
+Exit the IRC and the running process.
+
 =head1 SEE ALSO
 
 L<Bot::BasicBot::Pluggable>
